@@ -1,12 +1,10 @@
 set_dftbl_hooks <- function() {
-  width <- 40
+  width <- 36
 
   set_dftbl_opts_hook(width)
   set_dftbl_knit_hook(width)
   set_dftbl_source_hook()
   set_dftbl_chunk_hook()
-  set_dftbl_error_hook()
-  set_dftbl_warning_hook()
 }
 
 # Defines a `dftbl` knitr option. If this chunk option is set, code is duplicated
@@ -53,19 +51,24 @@ same_as_tbl_code <- function(df_code, tbl_code) {
 }
 
 same_as_tbl <- function(df, tbl) {
-  if (length(df) != length(tbl)) return(FALSE)
-  if (length(df) < 2) return(FALSE)
+  if (length(df) != length(tbl)) {
+    return(FALSE)
+  }
+  if (length(df) < 2) {
+    return(FALSE)
+  }
   df <- df[-1]
   tbl <- tbl[-1]
 
   df_obj <- df[[length(df)]]
   tbl_obj <- tbl[[length(tbl)]]
 
-  if (is.data.frame(df_obj) != is.data.frame(tbl_obj)) return(FALSE)
+  if (is.data.frame(df_obj) != is.data.frame(tbl_obj)) {
+    return(FALSE)
+  }
 
   if (is.data.frame(tbl_obj)) {
     df[[length(df)]] <- as_tibble_deep(df_obj)
-
   }
 
   identical(df, tbl)
@@ -121,7 +124,12 @@ set_dftbl_source_hook <- function() {
 
   dftbl_source_hook <- function(x, options) {
     nonempty <- which(x != "")
-    x[nonempty] <- vapply(x[nonempty], old_source_hook, options, FUN.VALUE = character(1))
+    x[nonempty] <- vapply(
+      x[nonempty],
+      old_source_hook,
+      options,
+      FUN.VALUE = character(1)
+    )
     if (isTRUE(options$dftbl)) {
       x <- vapply(x, dftbl_source_hook_one, FUN.VALUE = character(1))
     }
@@ -141,7 +149,11 @@ set_dftbl_chunk_hook <- function() {
   dftbl_chunk_hook <- function(x, options) {
     x <- old_chunk_hook(x, options)
     if (isTRUE(options$dftbl)) {
-      x <- paste0('<table class="dftbl"><tbody><tr><td>\n\n', x, "\n\n</td></tr></tbody></table>")
+      x <- paste0(
+        '<table class="dftbl"><tbody><tr><td>\n\n',
+        x,
+        "\n\n</td></tr></tbody></table>"
+      )
       x <- gsub("<tr><td>\n\n</td></tr>", "", x, fixed = TRUE)
     }
     x
@@ -149,41 +161,3 @@ set_dftbl_chunk_hook <- function() {
 
   knitr::knit_hooks$set(chunk = dftbl_chunk_hook)
 }
-
-# I don't understand why knitr doesn't wrap error output.
-set_dftbl_error_hook <- function() {
-  # Need to use a closure here to daisy-chain hooks
-
-  old_error_hook <- knitr::knit_hooks$get("error")
-
-  dftbl_error_hook <- function(x, options) {
-    if (isTRUE(options$dftbl)) {
-      x <- strsplit(x, "\n", fixed = TRUE)[[1]]
-      x <- unlist(map(x, fansi::strwrap_sgr, getOption("width") + 4, prefix = "#> ", initial = ""))
-      x <- paste(paste0(x, "\n"), collapse = "")
-    }
-    x <- old_error_hook(x, options)
-    paste0('<div class="error">', x, '</div>')
-  }
-
-  knitr::knit_hooks$set(error = dftbl_error_hook)
-}
-
-# I don't understand why knitr doesn't wrap warning output.
-set_dftbl_warning_hook <- function() {
-  # Need to use a closure here to daisy-chain hooks
-
-  old_warning_hook <- knitr::knit_hooks$get("warning")
-
-  dftbl_warning_hook <- function(x, options) {
-    if (isTRUE(options$dftbl)) {
-      x <- strsplit(x, "\n", fixed = TRUE)[[1]]
-      x <- unlist(map(x, fansi::strwrap_sgr, getOption("width") + 4, prefix = "#> ", initial = ""))
-      x <- paste(paste0(x, "\n"), collapse = "")
-    }
-    x <- old_warning_hook(x, options)
-    paste0('<div class="warning">', x, '</div>')
-  }
-
-  knitr::knit_hooks$set(warning = dftbl_warning_hook)
-}
