@@ -10,45 +10,45 @@ test_that("can add new row", {
 })
 
 test_that("add_row() keeps class of object", {
-  iris_new <- add_row(iris, Species = "unknown")
-  expect_equal(class(iris), class(iris_new))
+  trees_new <- add_row(trees, Volume = NA)
+  expect_equal(class(trees), class(trees_new))
 
-  iris_new <- add_row(as_tibble(iris), Species = "unknown")
-  expect_equal(class(as_tibble(iris)), class(iris_new))
+  trees_new <- add_row(as_tibble(trees), Volume = NA)
+  expect_equal(class(as_tibble(trees)), class(trees_new))
 })
 
 test_that("add_row() keeps class of object when adding in the middle", {
-  iris_new <- add_row(iris, Species = "unknown", .after = 10)
-  expect_equal(class(iris), class(iris_new))
+  trees_new <- add_row(trees, Volume = NA, .after = 10)
+  expect_equal(class(trees), class(trees_new))
 
-  iris_new <- add_row(as_tibble(iris), Species = "unknown")
-  expect_equal(class(as_tibble(iris)), class(iris_new))
+  trees_new <- add_row(as_tibble(trees), Volume = NA)
+  expect_equal(class(as_tibble(trees)), class(trees_new))
 })
 
 test_that("add_row() keeps class of object when adding in the beginning", {
-  iris_new <- add_row(iris, Species = "unknown", .after = 0)
-  expect_equal(class(iris), class(iris_new))
+  trees_new <- add_row(trees, Volume = NA, .after = 0)
+  expect_equal(class(trees), class(trees_new))
 
-  iris_new <- add_row(as_tibble(iris), Species = "unknown")
-  expect_equal(class(as_tibble(iris)), class(iris_new))
+  trees_new <- add_row(as_tibble(trees), Volume = NA)
+  expect_equal(class(as_tibble(trees)), class(trees_new))
 })
 
 test_that("adds empty row if no arguments", {
-  iris1 <- add_row(iris)
-  expect_equal(nrow(iris1), nrow(iris) + 1)
-  new_iris_row <- iris1[nrow(iris1), , drop = TRUE]
-  expect_true(all(is.na(new_iris_row)))
+  trees1 <- add_row(trees)
+  expect_equal(nrow(trees1), nrow(trees) + 1)
+  new_trees_row <- trees1[nrow(trees1), , drop = TRUE]
+  expect_true(all(is.na(new_trees_row)))
 })
 
 test_that("error if adding row with unknown variables", {
-  expect_tibble_error(
+  expect_tibble_abort(
     add_row(tibble(a = 3), xxyzy = "err"),
-    error_incompatible_new_rows("xxyzy")
+    abort_incompatible_new_rows("xxyzy")
   )
 
-  expect_tibble_error(
+  expect_tibble_abort(
     add_row(tibble(a = 3), b = "err", c = "oops"),
-    error_incompatible_new_rows(c("b", "c"))
+    abort_incompatible_new_rows(c("b", "c"))
   )
 })
 
@@ -65,12 +65,12 @@ test_that("can add multiple rows", {
 })
 
 test_that("can recycle when adding rows", {
-  iris_new <- add_row(iris, Sepal.Length = -1:-2, Species = "unknown")
-  expect_identical(nrow(iris_new), nrow(iris) + 2L)
-  expect_identical(iris_new$Sepal.Length, c(iris$Sepal.Length, -1:-2))
+  trees_new <- add_row(trees, Height = -1:-2, Volume = 2:3)
+  expect_identical(nrow(trees_new), nrow(trees) + 2L)
+  expect_identical(trees_new$Height, c(trees$Height, -1:-2))
   expect_identical(
-    as.character(iris_new$Species),
-    c(as.character(iris$Species), "unknown", "unknown")
+    trees_new$Volume,
+    c(trees$Volume, 2:3)
   )
 })
 
@@ -95,26 +95,38 @@ test_that("can add row inbetween", {
 test_that("can safely add to factor columns everywhere (#296)", {
   df <- tibble(a = factor(letters[1:3]))
   expect_identical(add_row(df), tibble(a = factor(c(letters[1:3], NA))))
-  expect_identical(add_row(df, .before = 1), tibble(a = factor(c(NA, letters[1:3]))))
-  expect_identical(add_row(df, .before = 2), tibble(a = factor(c("a", NA, letters[2:3]))))
+  expect_identical(
+    add_row(df, .before = 1),
+    tibble(a = factor(c(NA, letters[1:3])))
+  )
+  expect_identical(
+    add_row(df, .before = 2),
+    tibble(a = factor(c("a", NA, letters[2:3])))
+  )
   expect_identical(add_row(df, a = "d"), tibble(a = c(letters[1:4])))
-  expect_identical(add_row(df, a = "d", .before = 1), tibble(a = c("d", letters[1:3])))
-  expect_identical(add_row(df, a = "d", .before = 2), tibble(a = c("a", "d", letters[2:3])))
+  expect_identical(
+    add_row(df, a = "d", .before = 1),
+    tibble(a = c("d", letters[1:3]))
+  )
+  expect_identical(
+    add_row(df, a = "d", .before = 2),
+    tibble(a = c("a", "d", letters[2:3]))
+  )
 })
 
 test_that("error if both .before and .after are given", {
   df <- tibble(a = 1:3)
-  expect_tibble_error(
+  expect_tibble_abort(
     add_row(df, a = 4:5, .after = 2, .before = 3),
-    error_both_before_after()
+    abort_both_before_after()
   )
 })
 
 test_that("missing row names stay missing when adding row", {
-  expect_false(has_rownames(iris))
-  expect_false(has_rownames(add_row(iris, Species = "unknown", .after = 0)))
-  expect_false(has_rownames(add_row(iris, Species = "unknown", .after = nrow(iris))))
-  expect_false(has_rownames(add_row(iris, Species = "unknown", .before = 10)))
+  expect_false(has_rownames(trees))
+  expect_false(has_rownames(add_row(trees, Volume = NA, .after = 0)))
+  expect_false(has_rownames(add_row(trees, Volume = NA, .after = nrow(trees))))
+  expect_false(has_rownames(add_row(trees, Volume = NA, .before = 10)))
 })
 
 test_that("adding to a list column adds a NULL value (#148)", {
@@ -131,9 +143,9 @@ test_that("add_row() keeps the class of empty columns", {
 
 test_that("add_row() fails nicely for grouped data frames (#179)", {
   skip_if_not_installed("dplyr")
-  expect_tibble_error(
-    add_row(dplyr::group_by(iris, Species), Petal.Width = 3),
-    error_add_rows_to_grouped_df()
+  expect_tibble_abort(
+    add_row(dplyr::group_by(trees, Volume), Height = 3),
+    abort_add_rows_to_grouped_df()
   )
 })
 
@@ -152,7 +164,13 @@ test_that("add_row() works when adding zero row input (#809)", {
 test_that("can add new column", {
   df_all_new <- add_column(df_all, j = 1:3, k = 3:1)
   expect_identical(nrow(df_all_new), nrow(df_all))
-  expect_identical(df_all_new[seq_along(df_all)], df_all)
+
+  # Since the switch to vctrs the `tzone` attribute is set in
+  # `df_all_new`. Test with `equal` instead of `identical`. Also
+  # `dplyr:::all.equal.tbl_df()` somehow fails with a type error
+  # (dplyr 0.8.3), so we bypass the method.
+  expect_true(all.equal.default(df_all_new[seq_along(df_all)], df_all))
+
   expect_identical(df_all_new$j, 1:3)
   expect_identical(df_all_new$k, 3:1)
 })
@@ -167,49 +185,52 @@ test_that("add_column() works with 0-col tibbles (#786)", {
 })
 
 test_that("add_column() keeps class of object", {
-  iris_new <- add_column(iris, x = 1:150)
-  expect_equal(class(iris), class(iris_new))
+  trees_new <- add_column(trees, x = 1:31)
+  expect_equal(class(trees), class(trees_new))
 
-  iris_new <- add_column(as_tibble(iris), x = 1:150)
-  expect_equal(class(as_tibble(iris)), class(iris_new))
+  trees_new <- add_column(as_tibble(trees), x = 1:31)
+  expect_equal(class(as_tibble(trees)), class(trees_new))
 })
 
 test_that("add_column() keeps class of object when adding in the middle", {
-  iris_new <- add_column(iris, x = 1:150, .after = 3)
-  expect_equal(class(iris), class(iris_new))
+  trees_new <- add_column(trees, x = 1:31, .after = 3)
+  expect_equal(class(trees), class(trees_new))
 
-  iris_new <- add_column(as_tibble(iris), x = 1:150)
-  expect_equal(class(as_tibble(iris)), class(iris_new))
+  trees_new <- add_column(as_tibble(trees), x = 1:31)
+  expect_equal(class(as_tibble(trees)), class(trees_new))
 })
 
 test_that("add_column() keeps class of object when adding in the beginning", {
-  iris_new <- add_column(iris, x = 1:150, .after = 0)
-  expect_equal(class(iris), class(iris_new))
+  trees_new <- add_column(trees, x = 1:31, .after = 0)
+  expect_equal(class(trees), class(trees_new))
 
-  iris_new <- add_column(as_tibble(iris), x = 1:150)
-  expect_equal(class(as_tibble(iris)), class(iris_new))
+  trees_new <- add_column(as_tibble(trees), x = 1:31)
+  expect_equal(class(as_tibble(trees)), class(trees_new))
 })
 
 test_that("add_column() keeps unchanged if no arguments", {
-  expect_identical(iris, add_column(iris))
+  expect_identical(trees, add_column(trees))
 })
 
 test_that("add_column() can add to empty tibble or data frame", {
   expect_identical(add_column(tibble(.rows = 3), a = 1:3), tibble(a = 1:3))
-  expect_identical(add_column(as.data.frame(tibble(.rows = 3)), a = 1:3), data.frame(a = 1:3))
+  expect_identical(
+    add_column(as.data.frame(tibble(.rows = 3)), a = 1:3),
+    data.frame(a = 1:3)
+  )
 })
 
 test_that("error if adding existing columns", {
-  expect_tibble_error(
+  expect_tibble_abort(
     add_column(tibble(a = 3), a = 5),
-    error_column_names_must_be_unique("a", repair_hint = TRUE)
+    abort_column_names_must_be_unique("a", repair_hint = TRUE)
   )
 })
 
 test_that("error if adding wrong number of rows with add_column()", {
-  expect_tibble_error(
+  expect_tibble_abort(
     add_column(tibble(a = 3), b = 4:5),
-    error_incompatible_new_cols(1, data.frame(b = 4:5))
+    abort_incompatible_new_cols(1, data.frame(b = 4:5))
   )
 })
 
@@ -240,7 +261,10 @@ test_that("can recyle when adding multiple columns of length 1", {
 test_that("can recyle for zero-row data frame (#167)", {
   df <- tibble(a = 1:3)[0, ]
   df_new <- add_column(df, b = 4, c = character())
-  expect_identical(df_new, tibble(a = integer(), b = numeric(), c = character()))
+  expect_identical(
+    df_new,
+    tibble(a = integer(), b = numeric(), c = character())
+  )
 })
 
 test_that("can add as first column via .before = 1", {
@@ -269,21 +293,21 @@ test_that("can add column relative to named column", {
 
 test_that("error if both .before and .after are given", {
   df <- tibble(a = 1:3)
-  expect_tibble_error(
+  expect_tibble_abort(
     add_column(df, b = 4:6, .after = 2, .before = 3),
-    error_both_before_after()
+    abort_both_before_after()
   )
 })
 
 test_that("error if column named by .before or .after not found", {
   df <- tibble(a = 1:3)
-  expect_tibble_error(
+  expect_tibble_abort(
     add_column(df, b = 4:6, .after = "x"),
-    error_unknown_column_names("x")
+    abort_unknown_column_names("x")
   )
-  expect_tibble_error(
+  expect_tibble_abort(
     add_column(df, b = 4:6, .before = "x"),
-    error_unknown_column_names("x")
+    abort_unknown_column_names("x")
   )
 })
 
@@ -297,14 +321,14 @@ test_that("deprecated adding columns to non-data-frames", {
 })
 
 test_that("missing row names stay missing when adding column", {
-  expect_false(has_rownames(iris))
-  expect_false(has_rownames(add_column(iris, x = 1:150, .after = 0)))
-  expect_false(has_rownames(add_column(iris, x = 1:150, .after = ncol(iris))))
-  expect_false(has_rownames(add_column(iris, x = 1:150, .before = 2)))
+  expect_false(has_rownames(trees))
+  expect_false(has_rownames(add_column(trees, x = 1:31, .after = 0)))
+  expect_false(has_rownames(add_column(trees, x = 1:31, .after = ncol(trees))))
+  expect_false(has_rownames(add_column(trees, x = 1:31, .before = 2)))
 })
 
 test_that("output test", {
-  expect_snapshot_with_error({
+  expect_snapshot(error = TRUE, {
     add_row(tibble(), a = 1)
     add_row(tibble(), a = 1, b = 2)
     add_row(tibble(), !!!set_names(letters))
