@@ -223,7 +223,10 @@ test_that("[.tbl_df supports character subsetting (#312)", {
   scoped_lifecycle_silence()
 
   expect_identical(foo[as.character(9:12), ], foo[c(9:10, NA, NA), ])
-  expect_identical(foo[letters, ], foo[rlang::rep_along(letters, NA_integer_), ])
+  expect_identical(
+    foo[letters, ],
+    foo[rlang::rep_along(letters, NA_integer_), ]
+  )
   expect_identical(foo["9a", ], foo[NA_integer_, ])
 })
 
@@ -265,7 +268,10 @@ test_that("[.tbl_df supports character subsetting if row names are present (#312
 
   scoped_lifecycle_silence()
 
-  expect_identical(foo[letters, ], foo[rlang::rep_along(letters, NA_integer_), ])
+  expect_identical(
+    foo[letters, ],
+    foo[rlang::rep_along(letters, NA_integer_), ]
+  )
   expect_identical(foo["9a", ], foo[NA_integer_, ])
 })
 
@@ -324,17 +330,23 @@ test_that("[.tbl_df is careful about attributes (#155)", {
   expect_identical(attr(df[, "x"], "along for the ride"), "still here")
   expect_identical(attr(df[, 1:2], "along for the ride"), "still here")
   expect_identical(attr(df[, 2], "along for the ride"), "still here")
-  expect_identical(attr(df[, c(TRUE, FALSE)], "along for the ride"), "still here")
+  expect_identical(
+    attr(df[, c(TRUE, FALSE)], "along for the ride"),
+    "still here"
+  )
   expect_identical(attr(df[1, names(df)], "along for the ride"), "still here")
   expect_identical(attr(df[1, "x"], "along for the ride"), "still here")
   expect_identical(attr(df[1, 1:2], "along for the ride"), "still here")
   expect_identical(attr(df[1, 2], "along for the ride"), "still here")
-  expect_identical(attr(df[1, c(TRUE, FALSE)], "along for the ride"), "still here")
+  expect_identical(
+    attr(df[1, c(TRUE, FALSE)], "along for the ride"),
+    "still here"
+  )
 
   expect_identical(attr(df[1:2, ], "along for the ride"), "still here")
   expect_identical(attr(df[-1, ], "along for the ride"), "still here")
 
-  expect_identical(attr(df[, ], "along for the ride"), "still here")
+  expect_identical(attr(df[,], "along for the ride"), "still here")
   expect_identical(attr(df[], "along for the ride"), "still here")
 })
 
@@ -611,7 +623,10 @@ test_that("[<-.tbl_df supports matrix on the RHS (#762)", {
   expect_tibble_abort(
     df[1:3, 1:2] <- matrix(6:1, ncol = 2),
     abort_assign_incompatible_type(
-      df, as.data.frame(matrix(6:1, ncol = 2)), 2, quote(matrix(6:1, ncol = 2)),
+      df,
+      as.data.frame(matrix(6:1, ncol = 2)),
+      2,
+      quote(matrix(6:1, ncol = 2)),
       tryCatch(vctrs::vec_assign(letters, 1:3, 3:1), error = identity)
     )
   )
@@ -710,7 +725,7 @@ test_that("[<-.tbl_df is careful about attributes (#155)", {
   expect_identical(attr(df, "along for the ride"), "still here")
   expect_false(has_rownames(df))
 
-  df[, ] <- df
+  df[,] <- df
   expect_identical(attr(df, "along for the ride"), "still here")
   expect_false(has_rownames(df))
   df[] <- df
@@ -769,13 +784,19 @@ test_that("$<- recycles only values of length one", {
 
     expect_tibble_abort(
       df$a <- character(),
-      abort_assign_incompatible_size(3, list(character()), 1, NULL, quote(character()))
+      abort_assign_incompatible_size(
+        3,
+        list(character()),
+        1,
+        NULL,
+        quote(character())
+      )
     )
   })
 })
 
 test_that("output test", {
-  skip_if_not_installed("vctrs", "0.4.1.9000")
+  skip_if_not_installed("vctrs", "0.6.5.9000")
 
   expect_snapshot(error = TRUE, {
     "# [.tbl_df is careful about names (#1245)"
@@ -861,7 +882,7 @@ test_that("output test", {
     foo[[]]
     foo[[, 1]]
     foo[[1, ]]
-    foo[[, ]]
+    foo[[,]]
     foo[[1:3]]
     foo[[letters[1:3]]]
     foo[[TRUE]]
@@ -936,7 +957,7 @@ test_that("output test", {
     df[] <- list(0, 0)
     df[1, ] <- 1:3
     df[1:2, ] <- 1:3
-    df[, ] <- 1:2
+    df[,] <- 1:2
     df[1, ] <- list(a = 1:3, b = 1)
     df[1, ] <- list(a = 1, b = 1:3)
     df[1:2, ] <- list(a = 1:3, b = 1)
@@ -959,7 +980,10 @@ test_that("output test", {
     df[1:3, 1:3] <- NULL
 
     "# [<-.tbl_df and overwriting NA"
-    df <- tibble(x = rep(NA, 3), z = matrix(NA, ncol = 2, dimnames = list(NULL, c("a", "b"))))
+    df <- tibble(
+      x = rep(NA, 3),
+      z = matrix(NA, ncol = 2, dimnames = list(NULL, c("a", "b")))
+    )
     df[1, "x"] <- 5
     df[1, "z"] <- 5
     df
@@ -1016,7 +1040,7 @@ test_that("output test", {
     foo[[]] <- 1
     foo[[, 1]] <- 1
     foo[[1, ]] <- 1
-    foo[[, ]] <- 1
+    foo[[,]] <- 1
     foo[[1:3]] <- 1
     foo[[letters[1:3]]] <- 1
     foo[[TRUE]] <- 1
